# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from .. import _utilities, _tables
from . import outputs

__all__ = [
    'ca_material',
    'cert_material',
    'cert_path',
    'host',
    'key_material',
    'registry_auth',
]

__config__ = pulumi.Config('docker')

ca_material = __config__.get('caMaterial')
"""
PEM-encoded content of Docker host CA certificate
"""

cert_material = __config__.get('certMaterial')
"""
PEM-encoded content of Docker client certificate
"""

cert_path = __config__.get('certPath')
"""
Path to directory with Docker TLS config
"""

host = __config__.get('host') or (_utilities.get_env('DOCKER_HOST') or 'unix:///var/run/docker.sock')
"""
The Docker daemon address
"""

key_material = __config__.get('keyMaterial')
"""
PEM-encoded content of Docker client private key
"""

registry_auth = __config__.get('registryAuth')

